@@ -1,4 +1,4 @@
-# SPDX-FileCopyrightText: 2021 German Aerospace Center (DLR)
+# SPDX-FileCopyrightText: 2022 German Aerospace Center (DLR)
 #
 # SPDX-License-Identifier: MIT
 
@@ -15,9 +15,9 @@ from ..devices.shtxx import SHT85
 from ..devices.sfm3xxx import SFM3XXX
 from ..devices.bme280 import BME280
 from ..devices.scd30 import SCD30
-from ..devices.sdp.sdp8xx import SDP8XX
+from ..devices.sdp8xx import SDP8XX
 from ..devices.max31865 import MAX31865
-from ..devices.nau7802.nau7802 import NAU7802
+from ..devices.nau7802 import NAU7802
 from ..devices.ads1015 import ADS1015
 from ..devices.qwiicrelay import QwiicQuadRelay
 from ..devices.sps30 import SPS30
